bayespy.inference.vmp.nodes.gaussian.GaussianMoments.compute_fixed_moments
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianMoments.compute_fixed_moments